Crate apl_token_metadata

Crate apl_token_metadata 

Arch Network Token Metadata Standard

Modules

error
Error types
instruction
Instruction types
processor
Program state processor
state
State types and serialization sizes

Constants

ATTRIBUTES_SEED
PDA seed for attributes account
ID
The const program ID.
METADATA_SEED
PDA seed for metadata account

Functions

check_id
Returns true if given pubkey is the program ID.
check_program_account
Checks that the supplied program ID is the correct one for Arch Token Metadata
find_attributes_pda_with_program
Helper to derive the TokenMetadataAttributes PDA for a given mint
find_metadata_pda_with_program
Helper to derive the TokenMetadata PDA for a given mint
id
Returns the program ID.